==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebExporterEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExporterEventDetailDescriptionMetadata } from "./WebExporterEventDetailDescriptionMetadata";
import { WebExporterEventEventArgsDescription } from "./WebExporterEventEventArgsDescription";
/**
 * @hidden
 */
export let WebExporterEventEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebExporterEventEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebExporterEventEventArgsDescriptionMetadata.a == null) {
                WebExporterEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebExporterEventEventArgsDescriptionMetadata.c(WebExporterEventEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebExporterEventEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebExporterEventEventArgsDescriptionMetadata.a);
            WebExporterEventDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ExporterEventEventArgs");
            a.item("Detail", "ExportedType:WebExporterEventDetail");
        }
        static d(a) {
            WebExporterEventEventArgsDescriptionMetadata.b(a);
            a.aa("WebExporterEventEventArgs", () => new WebExporterEventEventArgsDescription());
            a.z("WebExporterEventEventArgs", WebExporterEventEventArgsDescriptionMetadata.a);
        }
    }
    WebExporterEventEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebExporterEventEventArgsDescriptionMetadata, 'WebExporterEventEventArgsDescriptionMetadata');
    WebExporterEventEventArgsDescriptionMetadata.a = null;
    return WebExporterEventEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebExporterEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExporterEventDetailDescriptionMetadata } from "./WebExporterEventDetailDescriptionMetadata";
import { WebExporterEventEventArgsDescription } from "./WebExporterEventEventArgsDescription";
/**
 * @hidden
 */
export let WebExporterEventEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebExporterEventEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebExporterEventEventArgsDescriptionMetadata.a == null) {
                WebExporterEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebExporterEventEventArgsDescriptionMetadata.c(WebExporterEventEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebExporterEventEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebExporterEventEventArgsDescriptionMetadata.a);
            WebExporterEventDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ExporterEventEventArgs");
            a.item("Detail", "ExportedType:WebExporterEventDetail");
        }
        static d(a) {
            WebExporterEventEventArgsDescriptionMetadata.b(a);
            a.ac("WebExporterEventEventArgs", () => new WebExporterEventEventArgsDescription());
            a.ab("WebExporterEventEventArgs", WebExporterEventEventArgsDescriptionMetadata.a);
        }
    }
    WebExporterEventEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebExporterEventEventArgsDescriptionMetadata, 'WebExporterEventEventArgsDescriptionMetadata');
    WebExporterEventEventArgsDescriptionMetadata.a = null;
    return WebExporterEventEventArgsDescriptionMetadata;
})();
